#HMapper_HardWired.py
# Description: Extracts counties affected by a selected hurricane and writes to a new file
# John Fay, Fall 2021

# Import arcpy module
import arcpy

# Set the user inputs
Storm_Name = "KATRINA"
Season = "2005" 
OutputFC = "..\\Data\\Impacted_Counties.shp" 

# Local variables:
TrackPointsFC = "..\\HurricaneMapper_II.gdb\\ibtracs_NEAtlantic"
USACountiesFC = "..\\Data\\USACounties.shp"

# Construct where clause and set the output feature layer/class varianbles
sqlString = f'"Season" = {Season} AND "Name" = \'{Storm_Name}\''
SelectedTrackPointsFC = "memory\\TrackPoints"
TrackLinesFC = "memory\\TrackLines"
USACountiesLyr = "USACountiesLyr"

# Process: Make Feature Layer
if arcpy.Exists(USACountiesLyr): arcpy.Delete_management(USACountiesLyr)
arcpy.MakeFeatureLayer_management(USACountiesFC, USACountiesLyr)
                                  
# Process: Select
arcpy.Select_analysis(TrackPointsFC, SelectedTrackPointsFC, sqlString)

# Process: Points To Line
arcpy.PointsToLine_management(SelectedTrackPointsFC, TrackLinesFC, "", "ISO_time", "NO_CLOSE")

# Process: Select Layer By Location
arcpy.SelectLayerByLocation_management(USACountiesLyr, "WITHIN_A_DISTANCE", TrackLinesFC, "500 Meters", "NEW_SELECTION")

# Process: Copy Features
arcpy.CopyFeatures_management(USACountiesLyr, OutputFC, "", "0", "0", "0")

