# HMapper_UserInput1.py
#
# Description:
#  Extracts counties affected by a selected hurricane and writes to a new file.
#  This version uses the sys.argv to accept inputs outside the script (e.g. from
#  ArcMap).
#
# John Fay, Fall 2021

# Import arcpy module
import arcpy, sys, os

# Get the user inputs via sys.argv 
Storm_Name = sys.argv[1]
Season = sys.argv[2] 
OutputFC = sys.argv[3]

# Local variables:
scriptPath = sys.argv[0]                     ## This is the full filename of the script (incl. its path)
scriptFolder = os.path.dirname(scriptPath)   ## This gets the folder in which the script lives.
rootFolder = os.path.dirname(scriptFolder)   ## This gets the folder in which the scripts folder lives, i.e. the root folder
dataFolder = os.path.join(rootFolder,'Data') ## This sets the data folder 
TrackPointsFC = os.path.join(rootFolder,"HurricaneMapper_II.gdb","ibtracs_NEAtlantic") ## Gets the TrackPointsFC in the data folder
USACountiesFC = os.path.join(dataFolder,"USACounties.shp")        ## Gets the USACountiesFC in the data folder

sqlString = f'"Season" = {Season} AND "Name" = \'{Storm_Name}\''
SelectedTrackPointsFC = "memory\\TrackPoints"
TrackLinesFC = "memory\\TrackLines"
USACountiesLyr = "USACountiesLyr"

# Process: Make Feature Layer
if arcpy.Exists(USACountiesLyr): arcpy.Delete_management(USACountiesLyr)
arcpy.MakeFeatureLayer_management(USACountiesFC, USACountiesLyr)
                                  
# Process: Select
arcpy.Select_analysis(TrackPointsFC, SelectedTrackPointsFC, sqlString)

# Process: Points To Line
arcpy.PointsToLine_management(SelectedTrackPointsFC, TrackLinesFC, "", "ISO_TIME", "NO_CLOSE")

# Process: Select Layer By Location
arcpy.SelectLayerByLocation_management(USACountiesLyr, "WITHIN_A_DISTANCE", TrackLinesFC, "500 Meters", "NEW_SELECTION")

# Process: Copy Features
arcpy.CopyFeatures_management(USACountiesLyr, OutputFC, "", "0", "0", "0")

