# HMapper_UserInput2.py
#
# Description:
#  Extracts counties affected by a selected hurricane and writes to a new file.
#  This version uses arcpy's "GetParameterAsText" to accept inputs outside the 
#  script (e.g. fromArcMap).

# Import arcpy module
import sys, os, arcpy

# Get the user inputs via ArcPy's GetParameter function 
Season = arcpy.GetParameterAsText(0) 
Storm_Name = arcpy.GetParameterAsText(1)
OutputFC = arcpy.GetParameterAsText(2)

# Local variables:
scriptPath = sys.argv[0]                     ## This is the full filename of the script (incl. its path)
scriptFolder = os.path.dirname(scriptPath)   ## This gets the folder in which the script lives.
rootFolder = os.path.dirname(scriptFolder)   ## This gets the folder in which the scripts folder lives, i.e. the root folder
dataFolder = os.path.join(rootFolder,'Data') ## This sets the data folder 
TrackPointsFC = "ibtracs_NEAtlantic"         ## Gets the TrackPointsFC in the default geodatabase
USACountiesFC = os.path.join(dataFolder,"USACounties.shp")        ## Gets the USACountiesFC in the data folder

sqlString = f'"Season" = {Season} AND "Name" = \'{Storm_Name}\''
SelectedTrackPointsFC = "memory\\TrackPoints"
TrackLinesFC = "memory\\TrackLines"
USACountiesLyr = "USACountiesLyr"

# Process: Make Feature Layer
if arcpy.Exists(USACountiesLyr): arcpy.Delete_management(USACountiesLyr)
arcpy.MakeFeatureLayer_management(USACountiesFC, USACountiesLyr)
                                  
# Process: Select
arcpy.Select_analysis(TrackPointsFC, SelectedTrackPointsFC, sqlString)

# Process: Points To Line
arcpy.PointsToLine_management(SelectedTrackPointsFC, TrackLinesFC, "", "ISO_TIME", "NO_CLOSE")

# Process: Select Layer By Location
arcpy.SelectLayerByLocation_management(USACountiesLyr, "WITHIN_A_DISTANCE", TrackLinesFC, "500 Meters", "NEW_SELECTION")

# Process: Copy Features
arcpy.CopyFeatures_management(USACountiesLyr, OutputFC, "", "0", "0", "0")

